************
Installation
************


Requirements
============

Astrocut has the following requirements:

- `Astropy`_ 
- `NumPy <http://www.numpy.org/>`_

  
Installing astrocut
===================

Using pip
---------

Astrocut is still in beta and not yet published to PyPi,
but you can still use pip to install it from github::

    pip git+https://github.com/spacetelescope/astrocut.git


From source
-----------

The latest development version of astrocut can be cloned from github
using this command::

    git clone https://github.com/spacetelescope/astrocut.git

To install astrocut (from the root of the source tree)::

    python setup.py install

   
